summaryrefslogtreecommitdiff
path: root/src/inc/corinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/inc/corinfo.h')
-rw-r--r--src/inc/corinfo.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/inc/corinfo.h b/src/inc/corinfo.h
index 9cc849043e..c3af9f8b78 100644
--- a/src/inc/corinfo.h
+++ b/src/inc/corinfo.h
@@ -1699,7 +1699,7 @@ struct CORINFO_CALL_INFO
CORINFO_CONST_LOOKUP instParamLookup; // Used by Ready-to-Run
- BOOL secureDelegateInvoke;
+ BOOL wrapperDelegateInvoke;
};
//----------------------------------------------------------------------------
@@ -1826,8 +1826,8 @@ struct CORINFO_EE_INFO
unsigned offsetOfDelegateInstance;
unsigned offsetOfDelegateFirstTarget;
- // Secure delegate offsets
- unsigned offsetOfSecureDelegateIndirectCell;
+ // Wrapper delegate offsets
+ unsigned offsetOfWrapperDelegateIndirectCell;
// Remoting offsets
unsigned offsetOfTransparentProxyRP;